@@ -16,6 +16,7 @@ APP_NAME=https-everywhere
 
 cd "`dirname $0`"
 RULESETS_SQLITE="$PWD/src/defaults/rulesets.sqlite"
+ANDROID_APP_ID=org.mozilla.firefox
 
 [ -d pkg ] || mkdir pkg
 
@@ -122,6 +123,7 @@ fi
 
 cd src
 
+
 # Build the XPI!
 rm -f "../$XPI_NAME"
 #zip -q -X -9r "../$XPI_NAME" . "-x@../.build_exclusions"
@@ -136,6 +138,21 @@ else
   echo >&2 "Total included rules: `sqlite3 $RULESETS_SQLITE 'select count(*) from rulesets'`"
   echo >&2 "Rules disabled by default: `find chrome/content/rules -name "*.xml" | xargs grep -F default_off | wc -l`"
   echo >&2 "Created $XPI_NAME"
+
+  # Push to Android Firefox if device is connected
+  # XXX on some systems, adb may require sudo...
+  if type adb > /dev/null && adb devices > /dev/null 2>/dev/null ; then
+    ADB_FOUND=`adb devices | tail -2 | head -1 | cut -f 1 | sed 's/ *$//g'`
+    if [ "$ADB_FOUND" != "List of devices attached" ]; then
+      echo Pushing "$XPI_NAME" to /sdcard/"$XPI_NAME"
+      adb push "../$XPI_NAME" /sdcard/"$XPI_NAME"
+      adb shell am start -a android.intent.action.VIEW \
+                         -c android.intent.category.DEFAULT \
+                         -d file:///mnt/sdcard/"$XPI_NAME" \
+                         -n $ANDROID_APP_ID/.App
+    fi
+  fi
+
   if [ -n "$BRANCH" ]; then
     cd ../..
     cp $SUBDIR/$XPI_NAME pkg
